==> bassline-7.x-1.0.tar.gz: bassline/template.php <==
<?php
/**
 * @file
 * Template.php file for the preprocessors and the likes
 */

/**
 * Include common functions used throughout the theme.
 */
include_once dirname(__FILE__) . '/theme_overrides/form.inc';
include_once dirname(__FILE__) . '/theme_overrides/menu.inc';
include_once dirname(__FILE__) . '/theme_overrides/theme.inc';
include_once dirname(__FILE__) . '/theme_overrides/views.inc';

/**
 * Implements template_preprocess().
 *
 * Global preprocess function.
 */
function bassline_preprocess(&$vars, $hook) {
  // Truncate the classes array for the following
  $truncate_classes = array('page', 'node', 'region', 'block', 'field', 'comment');
  if (in_array($hook, $truncate_classes)) {
    // empty the classes array to get rid of default classes
    array_splice($vars['classes_array'], 0);
    $vars['classes_array'][] = 'clearfix';
  }
  // Strip classes from HTML if they exist
  $html_class = array('html');
  $strip_classes = array('html', 'no-sidebars', '-node', '-node-', '-logged-', 'toolbar', 'toolbar-drawer');
  if (in_array($hook, $html_class)) {
    foreach($strip_classes as $class) {
      foreach ($vars['classes_array'] as $key => $value) {
        if(strpos($vars['classes_array'][$key], $class) !== false) {
          unset($vars['classes_array'][$key]);
        }
      }
    }
    $vars['classes_array'][] = 'clearfix';
  }
}

/**
 * Implements template_preprocess_html().
 */
function bassline_preprocess_html(&$vars) {
  // Add mobile meta tags
  $mobile_meta = array(
    '#tag' => 'meta',
    '#attributes' => array(
      'name' => 'viewport',
      'content' => 'width=device-width, initial-scale=1, maximum-scale=1'
    )
  );
  drupal_add_html_head($mobile_meta, 'bassline_mobile_meta');
}

/**
 * Implements template_preprocess_page().
 */
function bassline_preprocess_page(&$vars) {
}

/**
 * Implements template_preprocess_region().
 */
function bassline_preprocess_region(&$vars) {
}

/**
 * Implements template_preprocess_block().
 */
function bassline_preprocess_block(&$vars) {
  // add the id like this:
  // $vars['attributes_array']['id'] = $vars['block_html_id'];
}

/**
 * Implements template_preprocess_node().
 */
function bassline_preprocess_node(&$vars) {
  // Add suggestions to allow templates to target specific content types and view modes
  $vars['theme_hook_suggestions'][] = 'node__' . $vars['type'] . '__' . $vars['view_mode'];

  // Add classes based on node status
  if ($vars['promote']) {
    $vars['classes_array'][] = 'promoted';
  }
  if ($vars['sticky']) {
    $vars['classes_array'][] = 'sticky';
  }
  if ($vars['status'] =="0") {
    $vars['classes_array'][] = 'unpublished';
  }
}

/**
 * Implements template_preprocess_comment().
 */
function bassline_preprocess_comment(&$vars) {
}

/**
 * Implements hook_css_alter().
 *
 * Remove default drupal styles and some common contrib styles.
 */
function bassline_css_alter(&$css) {
  // Drupal core stylesheets
  // Aggregator
  if (module_exists('aggregator')) {
    unset($css['modules/aggregator/aggregator.css']);
  }
  // Book
  if (module_exists('book')) {
    unset($css['modules/book/book.css']);
  }
  // Comment
  if (module_exists('comment')) {
    unset($css['modules/comment/comment.css']);
  }
  // Forum
  if (module_exists('forum')) {
    unset($css['modules/forum/forum.css']);
  }
  // Poll
  if (module_exists('poll')) {
    unset($css['modules/poll/poll.css']);
  }
  // Search
  if (module_exists('search')) {
    unset($css['modules/search/search.css']);
  }
  // Field
  unset($css['modules/field/theme/field.css']);
  // Node
  unset($css['modules/node/node.css']);
  // System
  unset($css['modules/system/system.menus.css']);
  unset($css['modules/system/system.theme.css']);
  unset($css['modules/system/system.base.css']);
  unset($css['modules/system/system.messages.css']);
  // User
  unset($css['modules/user/user.css']);

  // Contrib stylesheets
  // Views
  if (module_exists('views')) {
    $views = drupal_get_path('module', 'views');
    unset($css[$views . '/css/views.css']);
  }
  // Ctools
  if (module_exists('views')) {
    $ctools = drupal_get_path('module', 'ctools');
    unset($css[$ctools . '/css/ctools.css']);
    unset($css[$ctools . '/css/modal.css']);
  }

}

==> bassline-7.x-1.1.tar.gz: bassline/template.php <==
<?php
/**
 * @file
 * Template.php file for the preprocessors and the likes.
 */

/**
 * Include common functions used throughout the theme.
 */
include_once dirname(__FILE__) . '/theme_overrides/form.inc';
include_once dirname(__FILE__) . '/theme_overrides/menu.inc';
include_once dirname(__FILE__) . '/theme_overrides/theme.inc';

/**
 * Implements template_preprocess().
 *
 * Global preprocess function.
 */
function bassline_preprocess(&$vars, $hook) {
  // Truncate the classes array for the following.
  $truncate_classes = array(
    'page',
    'node',
    'region',
    'block',
    'field',
    'comment'
  );

  if (in_array($hook, $truncate_classes)) {
    // Empty the classes array to get rid of default classes.
    array_splice($vars['classes_array'], 0);
    $vars['classes_array'][] = 'clearfix';
  }
  // Strip classes from HTML if they exist.
  $html_class = array('html');
  $strip_classes = array(
    'html',
    'no-sidebars',
    '-node',
    '-node-',
    '-logged-',
    'toolbar',
    'toolbar-drawer'
  );

  if (in_array($hook, $html_class)) {
    foreach ($strip_classes as $class) {
      foreach ($vars['classes_array'] as $key => $value) {
        if (strpos($vars['classes_array'][$key], $class) !== FALSE) {
          unset($vars['classes_array'][$key]);
        }
      }
    }
    $vars['classes_array'][] = 'clearfix';
  }
}

/**
 * Implements template_preprocess_html().
 */
function bassline_preprocess_html(&$vars) {
  // Add mobile meta tags.
  $mobile_meta = array(
    '#tag' => 'meta',
    '#attributes' => array(
      'name' => 'viewport',
      'content' => 'width=device-width, initial-scale=1, maximum-scale=1'
    )
  );
  drupal_add_html_head($mobile_meta, 'bassline_mobile_meta');
}

/**
 * Implements template_preprocess_node().
 */
function bassline_preprocess_node(&$vars) {
  // Add suggestions to allow templates to target specific content types and view modes.
  $vars['theme_hook_suggestions'][] = 'node__' . $vars['type'] . '__' . $vars['view_mode'];

  // Add classes based on node status.
  if ($vars['promote']) {
    $vars['classes_array'][] = 'promoted';
  }
  if ($vars['sticky']) {
    $vars['classes_array'][] = 'sticky';
  }
  if ($vars['status'] == "0") {
    $vars['classes_array'][] = 'unpublished';
  }
}

/**
 * Implements template_preprocess_comment().
 */
function bassline_preprocess_comment(&$vars) {
}

/**
 * Implements hook_css_alter().
 *
 * Remove default drupal styles and some common contrib styles.
 */
function bassline_css_alter(&$css) {
  // Drupal core stylesheets.
  // Aggregator.
  if (module_exists('aggregator')) {
    unset($css['modules/aggregator/aggregator.css']);
  }
  // Book.
  if (module_exists('book')) {
    unset($css['modules/book/book.css']);
  }
  // Comment.
  if (module_exists('comment')) {
    unset($css['modules/comment/comment.css']);
  }
  // Forum.
  if (module_exists('forum')) {
    unset($css['modules/forum/forum.css']);
  }
  // Poll.
  if (module_exists('poll')) {
    unset($css['modules/poll/poll.css']);
  }
  // Search.
  if (module_exists('search')) {
    unset($css['modules/search/search.css']);
  }
  // Field.
  unset($css['modules/field/theme/field.css']);
  // Node.
  unset($css['modules/node/node.css']);
  // System.
  unset($css['modules/system/system.menus.css']);
  unset($css['modules/system/system.theme.css']);
  unset($css['modules/system/system.base.css']);
  unset($css['modules/system/system.messages.css']);
  // User.
  unset($css['modules/user/user.css']);

  // Contrib stylesheets.
  // Views.
  if (module_exists('views')) {
    $views = drupal_get_path('module', 'views');
    unset($css[$views . '/css/views.css']);
  }
  // Ctools.
  if (module_exists('ctools')) {
    $ctools = drupal_get_path('module', 'ctools');
    unset($css[$ctools . '/css/ctools.css']);
    unset($css[$ctools . '/css/modal.css']);
  }
}
